@@ -1,7 +1,11 @@
+# 2011-08-12 Kier Davis <kierdavis@gmail.com>
+#   Added simple Namespace class.
+
 # Text utilities
 import re
 import htmlentitydefs
 import time
+import sys
 from os.path import isfile, getsize
 
 url_re = re.compile(
@@ -12,6 +16,23 @@ url_re = re.compile(
     r'(?::\d+)?' # optional port
     r'(?:/?|/\S+)$', re.IGNORECASE)
 
+class Namespace(object):
+  def __init__(self, uri):
+    self._uri = uri
+  
+  def __getitem__(self, name):
+    return self._uri + name
+
+RDF = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
+RDFS = Namespace("http://www.w3.org/2000/01/rdf-schema#")
+OWL = Namespace("http://www.w3.org/2002/07/owl#")
+DC = Namespace("http://purl.org/dc/elements/1.1/")
+DCT = Namespace("http://purl.org/dc/terms/")
+OV = Namespace("http://open.vocab.org/terms/")
+FOAF = Namespace("http://xmlns.com/foaf/0.1/")
+GEO = Namespace("http://www.w3.org/2003/01/geo/wgs84_pos#")
+SKOS = Namespace("http://www.w3.org/2004/02/skos/core#")
+
 def slugify(str):
   removelist = ["a", "an", "as", "at", "before", "but", "by", "for","from","is", "in", "into", "like", "of", "off", "on", "onto","per","since", "than", "the", "this", "that", "to", "up", "via","with"];
   aslug = strip_markup(str)
@@ -111,24 +132,8 @@ def triple(s, p, o, lang_or_dt=''):
     ret += s
   
   ret += ' '
-  if p =='a':
+  if p == 'a':
     ret += '<http://www.w3.org/1999/02/22-rdf-syntax-ns#type>'
-  elif p.startswith('rdf:'):
-    ret += '<http://www.w3.org/1999/02/22-rdf-syntax-ns#%s>' % p[4:]
-  elif p.startswith('rdfs:'):
-    ret += '<http://www.w3.org/2000/01/rdf-schema#%s>' % p[5:]
-  elif p.startswith('owl:'):
-    ret += '<http://www.w3.org/2002/07/owl#%s>' % p[4:]
-  elif p.startswith('dc:'):
-    ret += '<http://purl.org/dc/terms/%s>' % p[3:]
-  elif p.startswith('ov:'):
-    ret += '<http://open.vocab.org/terms/%s>' % p[3:]
-  elif p.startswith('foaf:'):
-    ret += '<http://xmlns.com/foaf/0.1/%s>' % p[5:]
-  elif p.startswith('geo:'):
-    ret += '<http://www.w3.org/2003/01/geo/wgs84_pos#%s>' % p[4:]
-  elif p.startswith('skos:'):
-    ret += '<http://www.w3.org/2004/02/skos/core#%s>' % p[5:]
   else:
     ret += '<%s>' % p
   
@@ -215,3 +220,62 @@ def kasabi_store(dataset, filename):
     f.close()    
   else:
     print "File is too large. Convert to ntriples for automatic chunking"
+
+
+#~ Originally from titlecase.py v0.2
+#~ Original Perl version by: John Gruber http://daringfireball.net/ 10 May 2008
+#~ Python version by Stuart Colville http://muffinresearch.co.uk
+#~ License: http://www.opensource.org/licenses/mit-license.php
+
+
+
+SMALL = 'a|an|and|as|at|but|by|en|for|if|in|of|on|or|the|to|v\.?|via|vs\.?'
+PUNCT = "[!\"#$%&'‘()*+,-./:;?@[\\\\\\]_`{|}~]"
+
+SMALL_WORDS = re.compile(r'^(%s)$' % SMALL, re.I)
+INLINE_PERIOD = re.compile(r'[a-zA-Z][.][a-zA-Z]')
+UC_ELSEWHERE = re.compile(r'%s*?[a-zA-Z]+[A-Z]+?' % PUNCT)
+CAPFIRST = re.compile(r"^%s*?([A-Za-z])" % PUNCT)
+SMALL_FIRST = re.compile(r'^(%s*)(%s)\b' % (PUNCT, SMALL), re.I)
+SMALL_LAST = re.compile(r'\b(%s)%s?$' % (SMALL, PUNCT), re.I)
+SUBPHRASE = re.compile(r'([:.;?!][ ])(%s)' % SMALL)
+
+def titlecase(text):
+
+  """
+  Titlecases input text
+
+  This filter changes all words to Title Caps, and attempts to be clever
+  about *un*capitalizing SMALL words like a/an/the in the input.
+
+  The list of "SMALL words" which are not capped comes from
+  the New York Times Manual of Style, plus 'vs' and 'v'.
+
+  """
+
+  words = re.split('\s', text)
+  line = []
+  for word in words:
+      if INLINE_PERIOD.search(word) or UC_ELSEWHERE.match(word):
+          line.append(word)
+          continue
+      if SMALL_WORDS.match(word):
+          line.append(word.lower())
+          continue
+      line.append(CAPFIRST.sub(lambda m: m.group(0).upper(), word))
+
+  line = " ".join(line)
+
+  line = SMALL_FIRST.sub(lambda m: '%s%s' % (
+      m.group(1),
+      m.group(2).capitalize()
+  ), line)
+
+  line = SMALL_LAST.sub(lambda m: m.group(0).capitalize(), line)
+
+  line = SUBPHRASE.sub(lambda m: '%s%s' % (
+      m.group(1),
+      m.group(2).capitalize()
+  ), line)
+
+  return line
